Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
ApiGroups []string `yaml:"apiGroups"`
Downloads []ConfigurationDownload `yaml:"crds"`
Entries []string `yaml:"entries"`
GenPaths []string `yaml:"genPaths"`
IncludeHead bool `yaml:"includeHead"`
Kind Kind `yaml:"kind"`
KustomizePaths []string `yaml:"kustomizationPaths"`
Name string `yaml:"name"`
Namespace string `yaml:"namespace"`
Repository string `yaml:"repository"`
SearchPaths []string `yaml:"searchPaths"`
Values []ConfigurationValues `yaml:"valuesFiles"`
VersionPrefix string `yaml:"versionPrefix"`
VersionSuffix string `yaml:"versionSuffix"`
}
func UnmarshalConfigurations ¶
func UnmarshalConfigurations(reader io.Reader) ([]Configuration, error)
UnmarshalConfigurations validates and unpacks bytes from the reader as a list of configurations.
The jsonschema used for validating configurations is embedded.
func (*Configuration) ValuesFile ¶
func (c *Configuration) ValuesFile(version string) (map[string]any, error)
ValuesFile resolves the most relevant values file content from the configuration, note that versions are treated as semver, but any prefix/suffix extras will result in improper sorting
type ConfigurationDownload ¶
type ConfigurationValues ¶
Click to show internal directories.
Click to hide internal directories.